@@ -25,7 +25,6 @@
 
 #include "eog-thumb-view.h"
 #include "eog-list-store.h"
-#include "eog-pixbuf-cell-renderer.h"
 #include "eog-image.h"
 #include "eog-job-queue.h"
 
@@ -60,11 +59,6 @@ struct _EogThumbViewPrivate {
 
 /* Drag 'n Drop */
 
-static GtkTargetEntry target_table[] = {
-	{ "text/uri-list", 0, 0},
-};
-
-
 static void
 eog_thumb_view_finalize (GObject *object)
 {
@@ -505,7 +499,7 @@ eog_thumb_view_init (EogThumbView *thumbview)
 {
 	thumbview->priv = EOG_THUMB_VIEW_GET_PRIVATE (thumbview);
 
-	thumbview->priv->pixbuf_cell = eog_pixbuf_cell_renderer_new ();
+	thumbview->priv->pixbuf_cell = gtk_cell_renderer_pixbuf_new ();
 
 	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (thumbview),
 	      	  		    thumbview->priv->pixbuf_cell,
@@ -548,8 +542,9 @@ eog_thumb_view_init (EogThumbView *thumbview)
 			  G_CALLBACK (thumbview_on_parent_set_cb), NULL);
 
 	gtk_icon_view_enable_model_drag_source (GTK_ICON_VIEW (thumbview), 0,
-						target_table, G_N_ELEMENTS (target_table),
+						NULL, 0,
 						GDK_ACTION_COPY);
+	gtk_drag_source_add_uri_targets (GTK_WIDGET (thumbview));
 
 	g_signal_connect (G_OBJECT (thumbview), "drag-data-get",
 			  G_CALLBACK (thumbview_on_drag_data_get_cb), NULL);
@@ -821,6 +816,10 @@ eog_thumb_view_select_single (EogThumbView *thumbview,
 		case EOG_THUMB_VIEW_SELECT_LEFT:
 		case EOG_THUMB_VIEW_SELECT_LAST:
 			path = gtk_tree_path_new_from_indices (n_items - 1, -1);
+			break;
+		case EOG_THUMB_VIEW_SELECT_RANDOM:
+			path = gtk_tree_path_new_from_indices ((int)(((float)(n_items - 1) * rand()) / (float)(RAND_MAX + 1.f)), -1);
+			break;
 		}
 	} else {
 		list = gtk_icon_view_get_selected_items (GTK_ICON_VIEW (thumbview));
@@ -854,6 +853,11 @@ eog_thumb_view_select_single (EogThumbView *thumbview,
 		case EOG_THUMB_VIEW_SELECT_LAST:
 			gtk_tree_path_free (path);
 			path = gtk_tree_path_new_from_indices (n_items - 1, -1);
+			break;
+		case EOG_THUMB_VIEW_SELECT_RANDOM:
+			gtk_tree_path_free (path);
+			path = gtk_tree_path_new_from_indices ((int)(((float)(n_items - 1) * rand()) / (float)(RAND_MAX + 1.f)), -1);
+			break;
 		}
 	}
 
